==> v1.1.zip: wonx/XDisplay.h <==
#ifndef _XDisplay_h_INCLUDED_
#define _XDisplay_h_INCLUDED_

/*****************************************************************************/
/*                                                                   */
/*****************************************************************************/

/*****************************************************************************/
/* 饹                                                              */
/*****************************************************************************/

typedef struct _XDisplay * XDisplay;

/*****************************************************************************/
/* إåեΥ󥯥롼                                              */
/*****************************************************************************/

#include "wonx_include/key.h"

#include "WWLCDPanel.h"

/*****************************************************************************/
/* дؿ                                                          */
/*****************************************************************************/

unsigned int XDisplay_GetKeyPress(XDisplay x_display);
int XDisplay_GetLCDDraw(XDisplay x_display);

int XDisplay_GetColorMapPrint(XDisplay d);
int XDisplay_GetPalettePrint(XDisplay d);
int XDisplay_GetCharacterPrint(XDisplay d);
int XDisplay_GetSpritePrint(XDisplay d);

int XDisplay_SetColorMapPrint(XDisplay d, int f);
int XDisplay_SetPalettePrint(XDisplay d, int f);
int XDisplay_SetCharacterPrint(XDisplay d, int f);
int XDisplay_SetSpritePrint(XDisplay d, int f);

/*===========================================================================*/
/* ֥ȤȾõ                                                  */
/*===========================================================================*/

/*---------------------------------------------------------------------------*/
/* ֥Ȥ                                                        */
/*---------------------------------------------------------------------------*/

XDisplay XDisplay_Create(int width, int height);

/*---------------------------------------------------------------------------*/
/* ֥Ȥξõ                                                        */
/*---------------------------------------------------------------------------*/

XDisplay XDisplay_Destroy(XDisplay x_display);

/*---------------------------------------------------------------------------*/
/* XФȤƱ                                                           */
/*---------------------------------------------------------------------------*/

int XDisplay_Sync(XDisplay x_display);

/*---------------------------------------------------------------------------*/
/*                                                                       */
/*---------------------------------------------------------------------------*/

int XDisplay_DrawLCDWindow(XDisplay x_display, WWLCDPanel ww_lcd_panel);

/*****************************************************************************/
/* ޤ                                                                  */
/*****************************************************************************/

#endif

/*****************************************************************************/
/* End of File.                                                              */
/*****************************************************************************/

==> v2.1.zip: wonx/XDisplay.h <==
#ifndef _XDisplay_h_INCLUDED_
#define _XDisplay_h_INCLUDED_

/*****************************************************************************/
/*                                                                   */
/*****************************************************************************/

/*****************************************************************************/
/* 饹                                                              */
/*****************************************************************************/

typedef struct _XDisplay * XDisplay;

/*****************************************************************************/
/* إåեΥ󥯥롼                                              */
/*****************************************************************************/

#include <X11/Xlib.h>

#include "wonx_include/key.h"

#include "WWDisplay.h"
#include "WWLCDPanel.h"
#include "XColorGC.h"

/*****************************************************************************/
/* дؿ                                                          */
/*****************************************************************************/

Display * XDisplay_GetDisplay(XDisplay x_display);
Colormap XDisplay_GetColormap(XDisplay x_display);

XColorGCDatabase XDisplay_GetColorGCDatabase(XDisplay x_display);

unsigned int XDisplay_GetKeyPress(XDisplay x_display);
int XDisplay_GetLCDDraw(XDisplay x_display);

int XDisplay_GetColorMapPrint(XDisplay d);
int XDisplay_GetPalettePrint(XDisplay d);
int XDisplay_GetCharacterPrint(XDisplay d);
int XDisplay_GetSpritePrint(XDisplay d);

int XDisplay_SetColorMapPrint(XDisplay d, int f);
int XDisplay_SetPalettePrint(XDisplay d, int f);
int XDisplay_SetCharacterPrint(XDisplay d, int f);
int XDisplay_SetSpritePrint(XDisplay d, int f);

/*===========================================================================*/
/* ֥ȤȾõ                                                  */
/*===========================================================================*/

/*---------------------------------------------------------------------------*/
/* ֥Ȥ                                                        */
/*---------------------------------------------------------------------------*/

XDisplay XDisplay_Create(int width, int height);

/*---------------------------------------------------------------------------*/
/* ֥Ȥξõ                                                        */
/*---------------------------------------------------------------------------*/

XDisplay XDisplay_Destroy(XDisplay x_display);

/*---------------------------------------------------------------------------*/
/* XФȤƱ                                                           */
/*---------------------------------------------------------------------------*/

int XDisplay_Sync(XDisplay x_display);

/*---------------------------------------------------------------------------*/
/*                                                                       */
/*---------------------------------------------------------------------------*/

int XDisplay_DrawLCDWindow(XDisplay x_display, WWDisplay ww_display,
			   WWLCDPanel ww_lcd_panel);

/*---------------------------------------------------------------------------*/
/* GC κ                                                                 */
/*---------------------------------------------------------------------------*/

GC XDisplay_CreateGC(XDisplay x_display);

/*---------------------------------------------------------------------------*/
/* GC β                                                                 */
/*---------------------------------------------------------------------------*/

int XDisplay_DestroyGC(XDisplay x_display, GC gc);

/*****************************************************************************/
/* ޤ                                                                  */
/*****************************************************************************/

#endif

/*****************************************************************************/
/* End of File.                                                              */
/*****************************************************************************/
